package com.ruoyi.nanjing.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TSyStationparameternotesMapper;
import com.ruoyi.nanjing.domain.TSyStationparameternotes;
import com.ruoyi.nanjing.service.ITSyStationparameternotesService;
import com.ruoyi.common.core.text.Convert;

/**
 * 工位参数定义Service业务层处理
 * 
 * @author limy
 * @date 2021-01-27
 */
@Service
public class TSyStationparameternotesServiceImpl implements ITSyStationparameternotesService 
{
    @Autowired
    private TSyStationparameternotesMapper tSyStationparameternotesMapper;

    /**
     * 查询工位参数定义
     * 
     * @param id 工位参数定义ID
     * @return 工位参数定义
     */
    @Override
    public TSyStationparameternotes selectTSyStationparameternotesById(Long id)
    {
        return tSyStationparameternotesMapper.selectTSyStationparameternotesById(id);
    }

    /**
     * 查询工位参数定义列表
     * 
     * @param tSyStationparameternotes 工位参数定义
     * @return 工位参数定义
     */
    @Override
    public List<TSyStationparameternotes> selectTSyStationparameternotesList(TSyStationparameternotes tSyStationparameternotes)
    {
        return tSyStationparameternotesMapper.selectTSyStationparameternotesList(tSyStationparameternotes);
    }

    /**
     * 新增工位参数定义
     * 
     * @param tSyStationparameternotes 工位参数定义
     * @return 结果
     */
    @Override
    public int insertTSyStationparameternotes(TSyStationparameternotes tSyStationparameternotes)
    {
        return tSyStationparameternotesMapper.insertTSyStationparameternotes(tSyStationparameternotes);
    }

    /**
     * 修改工位参数定义
     * 
     * @param tSyStationparameternotes 工位参数定义
     * @return 结果
     */
    @Override
    public int updateTSyStationparameternotes(TSyStationparameternotes tSyStationparameternotes)
    {
        return tSyStationparameternotesMapper.updateTSyStationparameternotes(tSyStationparameternotes);
    }

    /**
     * 删除工位参数定义对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTSyStationparameternotesByIds(String ids)
    {
        return tSyStationparameternotesMapper.deleteTSyStationparameternotesByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除工位参数定义信息
     * 
     * @param id 工位参数定义ID
     * @return 结果
     */
    @Override
    public int deleteTSyStationparameternotesById(Long id)
    {
        return tSyStationparameternotesMapper.deleteTSyStationparameternotesById(id);
    }

    @Override
    public TSyStationparameternotes getParaVal(String stationID, String para) {
        return tSyStationparameternotesMapper.getParaVal(stationID,para);
    }

    @Override
    public List<TSyStationparameternotes> selectByStationID(String stationID) {
        return tSyStationparameternotesMapper.selectByStationID(stationID);
    }

}
